@@ -2,8 +2,11 @@
 # Copyright © 2021 Wacom. All rights reserved.
 import abc
 import enum
+from datetime import datetime
 from typing import List, Dict, Any, NewType, Optional
 
+import dateutil.parser
+
 #  ---------------------------------------- Type definitions -----------------------------------------------------------
 LanguageCode = NewType("LanguageCode", str)
 ReferenceId = NewType("ReferenceId", str)
@@ -28,9 +31,9 @@ RDF_SCHEMA_LABEL: str = 'http://www.w3.org/2000/01/rdf-schema#label'
 ALIAS_TAG: str = 'alias'
 DATA_PROPERTY_TAG: str = 'literal'
 VALUE_TAG: str = 'value'
-LANGUAGE_CODE_TAG: str = 'languageCode'
 LOCALE_TAG: str = 'locale'
 DATA_PROPERTIES_TAG: str = 'literals'
+SEND_TO_NEL_TAG: str = 'sendToNEL'
 SOURCE_REFERENCE_ID_TAG: str = 'source_reference_id'
 SOURCE_SYSTEM_TAG: str = 'source_system'
 OBJECT_PROPERTIES_TAG: str = 'relations'
@@ -39,12 +42,15 @@ LOCALIZED_CONTENT_TAG: str = 'LocalizedContent'
 STATUS_FLAG_TAG: str = 'status'
 CONTENT_TAG: str = 'value'
 URI_TAG: str = 'uri'
+URIS_TAG: str = 'uris'
+ERRORS_TAG: str = 'errors'
 TEXT_TAG: str = 'text'
 TYPE_TAG: str = 'type'
 IMAGE_TAG: str = 'image'
 DESCRIPTION_TAG: str = 'description'
 COMMENT_TAG: str = 'text'
 DESCRIPTIONS_TAG: str = 'descriptions'
+USE_NEL_TAG: str = 'use_for_nel'
 RELATIONS_TAG: str = 'relations'
 LABELS_TAG: str = 'labels'
 IS_MAIN_TAG: str = 'isMain'
@@ -62,7 +68,7 @@ class EntityStatus(enum.Enum):
     Status of the entity synchronization (client and knowledge graph).
     """
     UNKNOWN = 0
-    """Unkown status."""
+    """Unknown status."""
     CREATED = 1
     """Entity has been created and not yet update."""
     UPDATED = 2
@@ -122,6 +128,7 @@ class Label(LocalizedContent):
     main: bool (default:=False)
         Main content
     """
+
     def __init__(self, content: str, language_code: LanguageCode = 'en_US', main: bool = False):
         self.__main: bool = main
         super().__init__(content, language_code)
@@ -132,7 +139,7 @@ class Label(LocalizedContent):
         return self.__main
 
     @staticmethod
-    def create_from_dict(dict_label: Dict[str, Any], tag_name: str = CONTENT_TAG, locale_name: str = LANGUAGE_CODE_TAG)\
+    def create_from_dict(dict_label: Dict[str, Any], tag_name: str = CONTENT_TAG, locale_name: str = LOCALE_TAG) \
             -> 'Label':
         if tag_name not in dict_label:
             raise ValueError("Dict is does not contain a localized label.")
@@ -150,7 +157,7 @@ class Label(LocalizedContent):
     def __dict__(self):
         return {
             CONTENT_TAG: self.content,
-            LANGUAGE_CODE_TAG: self.language_code,
+            LOCALE_TAG: self.language_code,
             IS_MAIN_TAG: self.main
         }
 
@@ -174,9 +181,9 @@ class Description(LocalizedContent):
 
     @staticmethod
     def create_from_dict(dict_description: Dict[str, Any]) -> 'Description':
-        if DESCRIPTION_TAG not in dict_description or LANGUAGE_CODE_TAG not in dict_description:
+        if DESCRIPTION_TAG not in dict_description or LOCALE_TAG not in dict_description:
             raise ValueError("Dict is does not contain a localized label.")
-        return Description(dict_description[DESCRIPTION_TAG], dict_description[LANGUAGE_CODE_TAG])
+        return Description(dict_description[DESCRIPTION_TAG], dict_description[LOCALE_TAG])
 
     @staticmethod
     def create_from_list(param: List[Dict[str, Any]]) -> List['Description']:
@@ -185,7 +192,7 @@ class Description(LocalizedContent):
     def __dict__(self):
         return {
             DESCRIPTION_TAG: self.content,
-            LANGUAGE_CODE_TAG: self.language_code,
+            LOCALE_TAG: self.language_code,
         }
 
 
@@ -208,9 +215,9 @@ class Comment(LocalizedContent):
 
     @staticmethod
     def create_from_dict(dict_description: Dict[str, Any]) -> 'Comment':
-        if DESCRIPTION_TAG not in dict_description or LANGUAGE_CODE_TAG not in dict_description:
+        if DESCRIPTION_TAG not in dict_description or LOCALE_TAG not in dict_description:
             raise ValueError("Dict is does not contain a localized comment.")
-        return Comment(dict_description[DESCRIPTION_TAG], dict_description[LANGUAGE_CODE_TAG])
+        return Comment(dict_description[DESCRIPTION_TAG], dict_description[LOCALE_TAG])
 
     @staticmethod
     def create_from_list(param: List[Dict[str, Any]]) -> List['Description']:
@@ -219,7 +226,7 @@ class Comment(LocalizedContent):
     def __dict__(self):
         return {
             DESCRIPTION_TAG: self.content,
-            LANGUAGE_CODE_TAG: self.language_code,
+            LOCALE_TAG: self.language_code,
         }
 
 
@@ -385,12 +392,13 @@ class OntologyContext(OntologyObject):
     """
 
     def __init__(self, cid: str, tenant_id: str, name: str, icon: str, labels: List[Label],
-                 comments: List[Comment], last_update: str, context: str, base_uri: str, version: int,
-                 settings: OntologyContextSettings):
+                 comments: List[Comment], date_added: datetime, date_modified: datetime, context: str, base_uri: str,
+                 version: int, settings: OntologyContextSettings):
         self.__id = cid
         self.__base_uri: str = base_uri
         self.__version: int = version
-        self.__last_update: str = last_update
+        self.__date_added: datetime = date_added
+        self.__date_modified: datetime = date_modified
         self.__settings: OntologyContextSettings = settings
         super().__init__(tenant_id, name, icon, labels, comments, context)
 
@@ -407,17 +415,20 @@ class OntologyContext(OntologyObject):
         context_data: Dict[str, Any] = context_dict['data']
         context_settings: Dict[str, Any] = context_data['settings']
         labels: List[Label] = [] if context_data['labels'] is None else \
-            [Label(content=la['text'], language_code=la['locale']) for la in context_data['labels']]
+            [Label(content=la[VALUE_TAG], language_code=la[LOCALE_TAG]) for la in context_data['labels']]
         comments: List[Comment] = [] if context_data['comments'] is None else \
-            [Comment(text=la['text'], language_code=la['locale']) for la in context_data['comments']]
+            [Comment(text=la[VALUE_TAG], language_code=la[LOCALE_TAG]) for la in context_data['comments']]
         settings: OntologyContextSettings = OntologyContextSettings(
             context_settings['rdfPrefix'], context_settings['rdfsPrefix'], context_settings['owlPrefix'],
             context_settings['baseLiteralUri'], context_settings['baseClassUri'],
             context_settings['descriptionLiteralName'], context_settings['depth']
         )
+        added: datetime = dateutil.parser.isoparse(context_data['dateAdded'])
+        modified: datetime = dateutil.parser.isoparse(context_data['dateModified'])
         return OntologyContext(context_data['id'], context_data['tenantId'], context_data['name'],
-                               context_data['icon'], labels, comments, context_data['lastUpdated'],
-                               context_data['context'], context_data['baseURI'], context_dict['version'],
+                               context_data['icon'], labels, comments, added, modified,
+                               context_data['context'], context_data['baseURI'],
+                               context_dict['version'],
                                settings)
 
     def __repr__(self):
