@@ -309,9 +309,9 @@ class OntologyClass(OntologyObject):
     @classmethod
     def from_dict(cls, concept_dict: Dict[str, Any]):
         labels: List[Label] = [] if concept_dict[LABELS_TAG] is None else \
-            [Label(content=la[VALUE_TAG], language_code=la[LANGUAGE_CODE_TAG]) for la in concept_dict[LABELS_TAG]]
+            [Label(content=la[VALUE_TAG], language_code=la[LOCALE_TAG]) for la in concept_dict[LABELS_TAG]]
         comments: List[Comment] = [] if concept_dict['comments'] is None else \
-            [Comment(text=la[VALUE_TAG], language_code=la[LANGUAGE_CODE_TAG]) for la in concept_dict['comments']]
+            [Comment(text=la[VALUE_TAG], language_code=la[LOCALE_TAG]) for la in concept_dict['comments']]
         return OntologyClass(tenant_id=concept_dict[TENANT_ID], context=concept_dict['context'],
                              reference=OntologyClassReference.parse(concept_dict[NAME_TAG]),
                              subclass_of=OntologyClassReference.parse(concept_dict[SUB_CLASS_OF_TAG]),
@@ -490,7 +490,7 @@ class DataProperty(EntityProperty):
     @staticmethod
     def create_from_dict(data_property_struct: dict):
         if CONTENT_TAG not in data_property_struct or \
-                LANGUAGE_CODE_TAG not in data_property_struct \
+                LOCALE_TAG not in data_property_struct \
                 and DATA_PROPERTY_TAG not in data_property_struct:
             raise ValueError("Dict is does not contain a data_property structure.")
         data_property_type: str = data_property_struct[DATA_PROPERTY_TAG]
@@ -502,12 +502,12 @@ class DataProperty(EntityProperty):
                 data_type = INVERSE_DATA_PROPERTY_TYPE_MAPPING[data_property_struct[DATA_TYPE_TAG]]
         return DataProperty(data_property_struct[CONTENT_TAG],
                             OntologyPropertyReference.parse(data_property_type),
-                            data_property_struct[LANGUAGE_CODE_TAG], data_type)
+                            data_property_struct[LOCALE_TAG], data_type)
 
     def __dict__(self):
         return {
             CONTENT_TAG: self.value,
-            LANGUAGE_CODE_TAG: self.language_code,
+            LOCALE_TAG: self.language_code,
             DATA_PROPERTY_TAG: self.data_property_type.iri,
             DATA_TYPE_TAG: None if self.data_type is None else self.data_type.value
         }
@@ -761,6 +761,7 @@ class ThingObject(abc.ABC):
     - **description**: Description of entity
     - **concept_type**: Type of the concept
     - **concept_type_info**: Information on the concept type
+    - **use_for_nel**: Use the entity for named entity linking
 
     Parameters
     ----------
@@ -782,7 +783,7 @@ class ThingObject(abc.ABC):
 
     def __init__(self, label: List[Label] = None, concept_type: OntologyClassReference = THING_CLASS,
                  description: Optional[List[Description]] = None, uri: Optional[str] = None, icon: Optional[str] = None,
-                 tenant_rights: TenantAccessRight = TenantAccessRight(), owner: bool = True):
+                 tenant_rights: TenantAccessRight = TenantAccessRight(), owner: bool = True, use_for_nel: bool = True):
         self.__uri: str = uri
         self.__icon: Optional[str] = icon
         self.__label: List[Label] = label if label else []
@@ -795,6 +796,7 @@ class ThingObject(abc.ABC):
         self.__status_flag: EntityStatus = EntityStatus.UNKNOWN
         self.__ontology_types: Optional[Set[str]] = None
         self.__owner: bool = owner
+        self.__use_for_nel: bool = use_for_nel
 
     @property
     def uri(self) -> str:
@@ -805,6 +807,15 @@ class ThingObject(abc.ABC):
     def uri(self, uri: str):
         self.__uri = uri
 
+    @property
+    def use_for_nel(self) -> bool:
+        """Use the entity for named entity linking."""
+        return self.__use_for_nel
+
+    @use_for_nel.setter
+    def use_for_nel(self, use_for_nel: bool):
+        self.__use_for_nel = use_for_nel
+
     @property
     def owner(self) -> bool:
         """Is current user the owner of the entity."""
@@ -866,9 +877,9 @@ class ThingObject(abc.ABC):
         language_code: LanguageCode
             ISO-3166 Country Codes and ISO-639 Language Codes in the format '<language_code>_<country>, e.g., en_US.
         """
-        for idx in range(len(self.label)):
-            if self.label[idx].language_code == language_code:
-                del self.__label[idx]
+        for idx, label in enumerate(self.label):
+            if label.language_code == language_code:
+                del self.label[idx]
                 break
 
     def label_lang(self, language_code: LanguageCode) -> Optional[Label]:
@@ -1102,9 +1113,9 @@ class ThingObject(abc.ABC):
             Returns a list of aliases for a specific language code
         """
         aliases: List[Label] = []
-        for a in self.alias:
-            if a.language_code == language_code:
-                aliases.append(a)
+        for alias in self.alias:
+            if alias.language_code == language_code:
+                aliases.append(alias)
         return aliases
 
     def update_alias(self, value: str, language_code: LanguageCode):
@@ -1206,6 +1217,8 @@ class ThingObject(abc.ABC):
         for desc in entity[DESCRIPTIONS_TAG]:
             descriptions.append(Description.create_from_dict(desc))
 
+        use_nel: bool = entity.get(USE_NEL_TAG, True)
+
         thing: ThingObject = ThingObject(label=labels, icon=entity[IMAGE_TAG], description=descriptions,
                                          uri=entity[URI_TAG],
                                          concept_type=OntologyClassReference.parse(entity[TYPE_TAG]),
@@ -1216,12 +1229,12 @@ class ThingObject(abc.ABC):
                     data_property_type: OntologyPropertyReference = \
                         OntologyPropertyReference.parse(data_property_type_str)
                     for data_property in data_properties:
-                        language_code: LanguageCode = LanguageCode(data_property[LANGUAGE_CODE_TAG])
+                        language_code: LanguageCode = LanguageCode(data_property[LOCALE_TAG])
                         value: str = data_property[VALUE_TAG]
                         thing.add_data_property(DataProperty(value, data_property_type, language_code))
             elif isinstance(entity[DATA_PROPERTIES_TAG], list):
                 for data_property in entity[DATA_PROPERTIES_TAG]:
-                    language_code: LanguageCode = LanguageCode(data_property[LANGUAGE_CODE_TAG])
+                    language_code: LanguageCode = LanguageCode(data_property[LOCALE_TAG])
                     value: str = data_property[VALUE_TAG]
                     data_property_type: OntologyPropertyReference = \
                         OntologyPropertyReference.parse(data_property[DATA_PROPERTY_TAG])
