@@ -15,6 +15,7 @@ from qwikidata.linked_data_interface import get_entity_dict_from_api, InvalidEnt
 from qwikidata.sparql import get_subclasses_of_item
 from qwikidata.typedefs import PropertyId, ItemId, LanguageCode
 
+from knowledge import logger
 from knowledge.public import PROPERTY_MAPPING
 from knowledge.utils.wikipedia import get_wikipedia_summary, get_wikipedia_summary_url
 
@@ -244,9 +245,9 @@ class WikiDataAPIClient(ABC):
 
     @staticmethod
     def __entity_image__(entity: WikidataItem):
-        p: WikidataClaimGroup = entity.get_claim_group(PropertyId(IMAGE_PROPERTY))
-        if len(p) > 0 and p[0].mainsnak.datavalue:
-            img: str = p[0].mainsnak.datavalue.value.replace(' ', '_')
+        claim_group: WikidataClaimGroup = entity.get_claim_group(PropertyId(IMAGE_PROPERTY))
+        if len(claim_group) > 0 and claim_group[0].mainsnak.datavalue:
+            img: str = claim_group[0].mainsnak.datavalue.value.replace(' ', '_')
             return WikiDataAPIClient.image_url(img)
         return ''
 
@@ -259,9 +260,9 @@ class WikiDataAPIClient(ABC):
 
     @staticmethod
     def __entity_type__(entity: WikidataItem) -> str:
-        p: WikidataClaimGroup = entity.get_claim_group(PropertyId('P31'))
-        if len(p) > 0:
-            type_entity = p[0].mainsnak.datavalue.value['id']
+        claim_group: WikidataClaimGroup = entity.get_claim_group(PropertyId('P31'))
+        if len(claim_group) > 0:
+            type_entity = claim_group[0].mainsnak.datavalue.value['id']
             return type_entity
         return ''
 
@@ -306,8 +307,8 @@ class WikiDataAPIClient(ABC):
                 val = prop[0]['mainsnak']['datavalue']['value']['time']
             elif data_type == 'quantity':
                 if 'amount' in prop[0]['mainsnak']['datavalue']['value']:
-                    val = '{} {}'.format(prop[0]['mainsnak']['datavalue']['value']['amount'],
-                                         prop[0]['mainsnak']['datavalue']['value']['unit'])
+                    val = f"{prop[0]['mainsnak']['datavalue']['value']['amount']} " \
+                          f"{prop[0]['mainsnak']['datavalue']['value']['unit']}"
 
             elif data_type == 'wikibase-lexeme':
                 val = prop[0]['mainsnak']['datavalue']['value']['id']
@@ -359,15 +360,15 @@ class WikiDataAPIClient(ABC):
         return response.json()
 
     @staticmethod
-    def __label__(v: dict, language: str):
-        if 'labels' in v and language in v['labels']:
-            return v['labels'][language]['value']
+    def __label__(label: dict, language: str):
+        if 'labels' in label and language in label['labels']:
+            return label['labels'][language]['value']
         return ''
 
     @staticmethod
-    def __description__(v: dict, language: str):
-        if 'descriptions' in v and language in v['descriptions']:
-            return v['descriptions'][language]['value']
+    def __description__(desc: dict, language: str):
+        if 'descriptions' in desc and language in desc['descriptions']:
+            return desc['descriptions'][language]['value']
         return ''
 
     @staticmethod
@@ -381,7 +382,6 @@ class WikiDataAPIClient(ABC):
                 image_url: str = WikiDataAPIClient.__entity_image_dict__(v['claims'][IMAGE_PROPERTY])
             else:
                 image_url: str = ''
-            type_uris: set = WikiDataAPIClient.__entity_type_dict__(v['claims'])
             label: str = WikiDataAPIClient.__label__(v, language)
             description: str = WikiDataAPIClient.__description__(v, language)
             # Collect the literals for entity
@@ -492,13 +492,13 @@ class WikiDataAPIClient(ABC):
         entity_dict: dict = get_entity_dict_from_api(ItemId(qid))
         entity: WikidataItem = WikidataItem(entity_dict)
         properties: dict = {}
-        for p, claim_group in entity.get_truthy_claim_groups().items():
+        for prop, claim_group in entity.get_truthy_claim_groups().items():
             literal = [
                 claim.mainsnak.datavalue.value
                 for claim in claim_group
                 if claim.mainsnak.snaktype == "value"
             ]
-            properties[p] = {
+            properties[prop] = {
                 'property-label': WikiDataAPIClient.property(p, LanguageCode(language)),
                 'values': literal
             }
@@ -537,13 +537,13 @@ class WikiDataAPIClient(ABC):
         entity: WikidataItem = WikidataItem(entity_dict)
         properties: Dict[str, dict] = {}
         # Properties
-        for p, claim_group in entity.get_truthy_claim_groups().items():
+        for prop, claim_group in entity.get_truthy_claim_groups().items():
             literal: List = [
                 claim.mainsnak.datavalue.value
                 for claim in claim_group
                 if claim.mainsnak.snaktype == "value"
             ]
-            properties[p] = {
+            properties[prop] = {
                 'property-label': WikiDataAPIClient.property(p, default_language),
                 'values': literal
             }
@@ -569,7 +569,7 @@ class WikiDataAPIClient(ABC):
 
     def references(self, qid: str, language: str = 'en'):
         references = []
-        entity, properties = self.entity_rels(qid, language)
+        _, properties = self.entity_rels(qid, language)
         if WikiDataAPIClient.PROPERTY_OFFICIAL_WEBSITE in properties:
             references.append({'property': properties[WikiDataAPIClient.PROPERTY_OFFICIAL_WEBSITE],
                                'property-label': PROPERTY_MAPPING[WikiDataAPIClient.PROPERTY_OFFICIAL_WEBSITE]})
@@ -610,7 +610,8 @@ class WikiDataAPIClient(ABC):
             else:
                 prop_dict = get_entity_dict_from_api(PropertyId(pid))
                 return WikidataProperty(prop_dict).get_label(LanguageCode(language))
-        except InvalidEntityId as e:
+        except InvalidEntityId as iei:
+            logger.exception(iei)
             return None
 
     @staticmethod
