@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2021 Wacom. All rights reserved.
 import enum
+import json
 import os
 import urllib.parse
 from typing import List, Dict, Any, Tuple, Optional
@@ -9,21 +10,21 @@ import requests
 from requests import Response
 
 from knowledge.base.access import TenantAccessRight
-from knowledge.base.entity import LanguageCode, DATA_PROPERTIES_TAG, DATA_PROPERTY_TAG, \
-    LANGUAGE_CODE_TAG, VALUE_TAG, IMAGE_TAG, DESCRIPTION_TAG, TYPE_TAG, URI_TAG, LABELS_TAG, IS_MAIN_TAG, \
-    DESCRIPTIONS_TAG, RELATIONS_TAG, EntityStatus, Label, Description
+from knowledge.base.entity import LanguageCode, DATA_PROPERTIES_TAG, DATA_PROPERTY_TAG, VALUE_TAG, IMAGE_TAG, \
+    DESCRIPTION_TAG, TYPE_TAG, URI_TAG, LABELS_TAG, IS_MAIN_TAG, DESCRIPTIONS_TAG, RELATIONS_TAG, SEND_TO_NEL_TAG, \
+    LOCALE_TAG, EntityStatus, Label, Description, URIS_TAG
 from knowledge.base.ontology import DataProperty, OntologyPropertyReference, ThingObject, OntologyClassReference, \
     ObjectProperty
 from knowledge.services import USER_AGENT_STR
-from knowledge.services.base import WacomServiceAPIClient, WacomServiceException
+from knowledge.services.base import WacomServiceAPIClient, WacomServiceException, AUTHORIZATION_HEADER_FLAG, \
+    USER_AGENT_HEADER_FLAG, CONTENT_TYPE_HEADER_FLAG
+
 # ------------------------------------------------- Constants ----------------------------------------------------------
 ACTIVATION_TAG: str = 'activation'
 SEARCH_TERM: str = 'searchTerm'
 LANGUAGE_PARAMETER: str = 'language'
 TYPES_PARAMETER: str = 'types'
 LIMIT_PARAMETER: str = 'limit'
-AUTHORIZATION_HEADER_FLAG: str = 'Authorization'
-CONTENT_TYPE_HEADER_FLAG: str = 'Content-Type'
 LISTING: str = 'listing'
 TOTAL_COUNT: str = 'totalCount'
 TARGET: str = 'target'
@@ -37,8 +38,7 @@ SUBJECT_URI: str = 'subjectUri'
 NEXT_PAGE_ID_TAG: str = 'nextPageId'
 TENANT_RIGHTS_TAG: str = 'tenantRights'
 RELATION_TAG: str = 'relation'
-USER_AGENT_TAG: str = "User-Agent"
-
+APPLICATION_JSON_HEADER: str = 'application/json'
 
 MIME_TYPE: Dict[str, str] = {
     '.jpg': 'image/jpeg',
@@ -88,6 +88,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
     PERSONAL_KNOWLEDGE_URL: str = 'https://stage-private-knowledge.wacom.com'
     USER_ENDPOINT: str = 'user'
     ENTITY_ENDPOINT: str = 'entity'
+    ENTITY_BULK_ENDPOINT: str = 'entity/bulk'
     ENTITY_IMAGE_ENDPOINT: str = 'entity/image/'
     ACTIVATIONS_ENDPOINT: str = 'entity/activations'
     ENTITY_URI_ENDPOINT: str = 'entity/{}'
@@ -132,7 +133,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_ENDPOINT}/{urllib.parse.quote(uri)}'
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -158,7 +159,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
                 for data_property in e[DATA_PROPERTIES_TAG]:
                     data_property_type: OntologyPropertyReference = \
                         OntologyPropertyReference.parse(data_property[DATA_PROPERTY_TAG])
-                    language_code: LanguageCode = data_property[LANGUAGE_CODE_TAG]
+                    language_code: LanguageCode = data_property[LOCALE_TAG]
                     value: str = data_property[VALUE_TAG]
                     thing.add_data_property(DataProperty(value, data_property_type, language_code))
             # Tenant rights
@@ -192,7 +193,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             raise WacomServiceException("Please delete less than 100 entities.")
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_ENDPOINT}'
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         params: Dict[str, Any] = {
@@ -224,7 +225,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_URI_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.delete(url, headers=headers, params={'forceDelete': force},
@@ -256,7 +257,109 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         except WacomServiceException:
             return False
 
-    def create_entity(self, auth_key: str, entity: ThingObject):
+    def __entity__(self, entity: ThingObject):
+        # Different localized content
+        labels: List[dict] = []
+        descriptions: List[dict] = []
+        literals: List[dict] = []
+        # Add description in different languages
+        for desc in entity.description:
+            if len(desc.content) > 0 and not desc.content == ' ':
+                descriptions.append({
+                    DESCRIPTION_TAG: desc.content,
+                    LOCALE_TAG: desc.language_code
+                })
+        if len(descriptions) == 0:
+            #  Adding an empty description
+            for label in entity.label:
+                if len(label.content) > 0 and not label.content == ' ':
+                    descriptions.append({
+                        DESCRIPTION_TAG: f'Description of {label.content}',
+                        LOCALE_TAG: label.language_code
+                    })
+
+        # Labels are tagged as main label
+        for label in entity.label:
+            if len(label.content) > 0 and label.content != " ":
+                labels.append({
+                    VALUE_TAG: label.content,
+                    LOCALE_TAG: label.language_code,
+                    IS_MAIN_TAG: True
+                })
+        # Alias are no main labels
+        for label in entity.alias:
+            if len(label.content) > 0 and label.content != " ":
+                labels.append({
+                    VALUE_TAG: label.content,
+                    LOCALE_TAG: label.language_code,
+                    IS_MAIN_TAG: False
+                })
+        # Labels are tagged as main label
+        for literal_property, list_literals in entity.data_properties.items():
+            for li in list_literals:
+                if li.data_property_type:
+                    literals.append({
+                        VALUE_TAG: li.value,
+                        LOCALE_TAG: li.language_code,
+                        DATA_PROPERTY_TAG: li.data_property_type.iri
+                    })
+        payload: Dict[str, Any] = {
+            TYPE_TAG: entity.concept_type.iri,
+            DESCRIPTIONS_TAG: descriptions,
+            LABELS_TAG: labels,
+            DATA_PROPERTIES_TAG: literals,
+            SEND_TO_NEL_TAG: entity.use_for_nel
+        }
+        if entity.tenant_access_right:
+            payload[TENANT_RIGHTS_TAG] = entity.tenant_access_right.to_list()
+        return payload
+
+    def create_entity_bulk(self, auth_key: str, entities: List[ThingObject], batch_size: int = 10) -> List[ThingObject]:
+        """
+        Creates entity in graph.
+
+        Parameters
+        ----------
+        auth_key: str
+            Auth key from user
+        entities: List[ThingObject]
+            Entities
+        batch_size: int
+            Batch size
+
+        Returns
+        -------
+        uri: str
+            URI of entity
+
+        Raises
+        ------
+        WacomServiceException
+            If the graph service returns an error code
+        """
+        url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_BULK_ENDPOINT}'
+        # Header info
+        headers: Dict[str, str] = {
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
+            CONTENT_TYPE_HEADER_FLAG: APPLICATION_JSON_HEADER,
+            AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
+        }
+        payload: List[Dict[str, Any]] = [self.__entity__(e) for e in entities]
+        for bulk_idx in range(0, len(entities), batch_size):
+            bulk = payload[bulk_idx:bulk_idx + batch_size]
+
+            response: Response = requests.post(url, json=bulk, headers=headers,
+                                               verify=self.verify_calls)
+            if response.ok:
+                response_dict: Dict[str, Any] = response.json()
+                for idx, uri in enumerate(response_dict[URIS_TAG]):
+                    if entities[bulk_idx + idx].image is not None and entities[bulk_idx + idx].image != '':
+                        self.set_entity_image_url(auth_key, uri, entities[bulk_idx + idx].image)
+                    entities[bulk_idx + idx].uri = response_dict[URIS_TAG][idx]
+
+        return entities
+
+    def create_entity(self, auth_key: str, entity: ThingObject) -> str:
         """
         Creates entity in graph.
 
@@ -278,73 +381,20 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             If the graph service returns an error code
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_ENDPOINT}'
-        # Different localized content
-        labels: List[dict] = []
-        descriptions: List[dict] = []
-        literals: List[dict] = []
+
         # Header info
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
-            'Content-Type': 'application/json',
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
+            CONTENT_TYPE_HEADER_FLAG: APPLICATION_JSON_HEADER,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
-        # Add description in different languages
-        for desc in entity.description:
-            if len(desc.content) > 0 and not desc.content == ' ':
-                descriptions.append({
-                    DESCRIPTION_TAG: desc.content,
-                    LANGUAGE_CODE_TAG: desc.language_code
-                })
-        if len(descriptions) == 0:
-            #  Adding an empty description
-            for label in entity.label:
-                if len(label.content) > 0 and not label.content == ' ':
-                    descriptions.append({
-                        DESCRIPTION_TAG: f'Description of {label.content}',
-                        LANGUAGE_CODE_TAG: label.language_code
-                    })
-
-        # Labels are tagged as main label
-        for label in entity.label:
-            if len(label.content) > 0 and label.content != " ":
-                labels.append({
-                    'value': label.content,
-                    LANGUAGE_CODE_TAG: label.language_code,
-                    'isMain': True
-                })
-        # Alias are no main labels
-        for label in entity.alias:
-            if len(label.content) > 0 and label.content != " ":
-                labels.append({
-                    'value': label.content,
-                    LANGUAGE_CODE_TAG: label.language_code,
-                    'isMain': False
-                })
-        # Labels are tagged as main label
-        for literal_property, list_literals in entity.data_properties.items():
-            for li in list_literals:
-                if li.data_property_type:
-                    literals.append({
-                        'value': li.value,
-                        LANGUAGE_CODE_TAG: li.language_code,
-                        DATA_PROPERTY_TAG: li.data_property_type.iri
-                    })
-        payload: dict = {
-            TYPE_TAG: entity.concept_type.iri,
-            DESCRIPTIONS_TAG: descriptions,
-            LABELS_TAG: labels,
-            DATA_PROPERTIES_TAG: literals
-        }
-        if entity.tenant_access_right:
-            payload[TENANT_RIGHTS_TAG] = entity.tenant_access_right.to_list()
+        payload: Dict[str, Any] = self.__entity__(entity)
         response: Response = requests.post(url, json=payload, headers=headers, verify=self.verify_calls)
         if response.ok:
             uri: str = response.json()[URI_TAG]
             if entity.image is not None and entity.image != '':
                 self.set_entity_image_url(auth_key, uri, entity.image)
             return uri
-
-        import json
         raise WacomServiceException(f'Pushing entity failed. '
                                     f'Response code:={response.status_code}, exception:= {response.content}. '
                                     f'Payload: \n{json.dumps(payload, indent=4)}')
@@ -378,8 +428,8 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         literals: List[dict] = []
         # Header info
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
-            'Content-Type': 'application/json',
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
+            CONTENT_TYPE_HEADER_FLAG: APPLICATION_JSON_HEADER,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         # Add description in different languages
@@ -387,7 +437,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             if len(desc.content) > 0 and not desc.content == ' ':
                 descriptions.append({
                     DESCRIPTION_TAG: desc.content,
-                    LANGUAGE_CODE_TAG: desc.language_code
+                    LOCALE_TAG: desc.language_code
                 })
         if len(descriptions) == 0:
             #  Adding an empty description
@@ -395,7 +445,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
                 if len(label.content) > 0 and not label.content == ' ':
                     descriptions.append({
                         DESCRIPTION_TAG: f'Description of {label.content}',
-                        LANGUAGE_CODE_TAG: label.language_code
+                        LOCALE_TAG: label.language_code
                     })
 
         # Labels are tagged as main label
@@ -403,7 +453,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             if len(label.content) > 0 and label.content != " ":
                 labels.append({
                     'value': label.content,
-                    LANGUAGE_CODE_TAG: label.language_code,
+                    LOCALE_TAG: label.language_code,
                     'isMain': True
                 })
         # Alias are no main labels
@@ -411,16 +461,16 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             if len(label.content) > 0 and label.content != " ":
                 labels.append({
                     'value': label.content,
-                    LANGUAGE_CODE_TAG: label.language_code,
+                    LOCALE_TAG: label.language_code,
                     'isMain': False
                 })
         # Labels are tagged as main label
-        for literal_property, list_literals in entity.data_properties.items():
+        for list_literals in entity.data_properties.values():
             for li in list_literals:
                 if li.data_property_type:
                     literals.append({
                         'value': li.value,
-                        LANGUAGE_CODE_TAG: li.language_code,
+                        LOCALE_TAG: li.language_code,
                         DATA_PROPERTY_TAG: li.data_property_type.iri
                     })
         payload: dict = {
@@ -433,7 +483,6 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             payload[TENANT_RIGHTS_TAG] = entity.tenant_access_right.to_list()
         response: Response = requests.patch(url, json=payload, headers=headers, verify=self.verify_calls)
         if not response.ok:
-            import json
             raise WacomServiceException(f'Pushing entity failed. '
                                         f'Response code:={response.status_code}, exception:= {response.content}. '
                                         f'Payload: \n{json.dumps(payload, indent=4)}')
@@ -461,7 +510,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.RELATIONS_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -494,7 +543,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.LABELS_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -529,7 +578,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.LITERAL_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -561,7 +610,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.RELATION_ENDPOINT.format(source)}'
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         params: dict = {
@@ -570,7 +619,6 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         }
         response: Response = requests.post(url, params=params, headers=headers, verify=self.verify_calls)
         if not response.ok:
-            import json
             raise WacomServiceException(f'Create relations failed. '
                                         f'Response code:={response.status_code}, exception:= {response.content}. '
                                         f'URL: {url}'
@@ -603,7 +651,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             TARGET: target
         }
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         # Get response
@@ -641,7 +689,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_url}/{self.service_endpoint}{WacomKnowledgeService.ACTIVATIONS_ENDPOINT}'
 
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         params: dict = {
@@ -697,7 +745,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_url}/{self.service_endpoint}{WacomKnowledgeService.LISTING_ENDPOINT}'
         # Header with auth token
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         # Parameter with filtering and limit
@@ -724,9 +772,8 @@ class WacomKnowledgeService(WacomServiceAPIClient):
                     entities.append(thing)
             return entities, total_number, next_page_id
         else:
-            raise WacomServiceException('Failed to list the entities (since:= {}, limit:={}). '
-                                        'Response code:={}, exception:= {}'
-                                        .format(page_id, limit, response.status_code, response.content))
+            raise WacomServiceException(f'Failed to list the entities (since:= {page_id}, limit:={limit}). '
+                                        f'Response code:={response.status_code}, exception:= {response.content}')
 
     def ontology_update(self, auth_key: str):
         """
@@ -748,7 +795,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ONTOLOGY_UPDATE_ENDPOINT}'
         # Header with auth token
         headers: dict = {
-            USER_AGENT_TAG: USER_AGENT_STR,
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.patch(url, headers=headers, verify=self.verify_calls)
@@ -757,7 +804,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
                                         f'Response code:={response.status_code}, exception:= {response.content}')
 
     def search_all(self, auth_key: str, search_term: str, language_code: LanguageCode,
-                   types: List[OntologyClassReference], limit: int = 30, next_page_id: str = None)\
+                   types: List[OntologyClassReference], limit: int = 30, next_page_id: str = None) \
             -> Tuple[List[ThingObject], str]:
         """Search term in labels, literals and description.
 
@@ -789,8 +836,8 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             If the graph service returns an error code.
         """
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
-            AUTHORIZATION_HEADER_FLAG:  f'Bearer {auth_key}'
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
+            AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         parameters: Dict[str, Any] = {
             SEARCH_TERM: search_term,
@@ -837,12 +884,12 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             If the graph service returns an error code.
         """
         headers: Dict[str, str] = {
-            USER_AGENT_TAG: USER_AGENT_STR,
-            AUTHORIZATION_HEADER_FLAG:  f'Bearer {auth_key}'
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
+            AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         parameters: Dict[str, Any] = {
             SEARCH_TERM: search_term,
-            LANGUAGE_PARAMETER: language_code,
+            LOCALE_TAG: language_code,
             LIMIT: limit,
             NEXT_PAGE_ID_TAG: next_page_id
         }
@@ -853,7 +900,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         raise WacomServiceException(f'Search on labels {search_term} failed. '
                                     f'Response code:={response.status_code}, exception:= {response.content}')
 
-    def search_literal(self, auth_key: str, search_term: str,  literal: OntologyPropertyReference,
+    def search_literal(self, auth_key: str, search_term: str, literal: OntologyPropertyReference,
                        pattern: SearchPattern = SearchPattern.REGEX,
                        language_code: LanguageCode = LanguageCode('en_US'),
                        limit: int = 30, next_page_id: str = None) -> Tuple[List[ThingObject], str]:
@@ -994,7 +1041,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_base_url}{WacomKnowledgeService.SEARCH_DESCRIPTION_ENDPOINT}'
         parameters: Dict[str, Any] = {
             SEARCH_TERM: search_term,
-            LANGUAGE_PARAMETER: language_code,
+            LOCALE_TAG: language_code,
             LIMIT: limit,
             NEXT_PAGE_ID_TAG: next_page_id
         }
@@ -1045,8 +1092,9 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         with requests.session() as session:
             headers: Dict[str, str] = {
-                USER_AGENT_TAG: f'ImageFetcher/0.1 (https://github.com/Wacom-Developer/personal-knowledge-library)'
-                              f' personal-knowledge-library/0.2.4'
+                USER_AGENT_HEADER_FLAG:
+                    'ImageFetcher/0.1 (https://github.com/Wacom-Developer/personal-knowledge-library)'
+                    ' personal-knowledge-library/0.2.4'
             }
             response: Response = session.get(image_url, headers=headers)
             if response.ok:
