@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2021 Wacom. All rights reserved.
+import json
 import urllib.parse
 from http import HTTPStatus
 from typing import Dict, List, Any, Optional, Tuple
@@ -10,12 +11,14 @@ from requests import Response
 from knowledge.base.entity import OntologyContext, LocalizedContent, Label, Comment
 from knowledge.base.ontology import OntologyClassReference, OntologyPropertyReference, OntologyProperty, OntologyClass,\
     PropertyType, THING_CLASS, DataPropertyType
+from knowledge.services import USER_AGENT_STR
 from knowledge.services.base import WacomServiceAPIClient, WacomServiceException
 from knowledge.services.graph import AUTHORIZATION_HEADER_FLAG
 
 # ------------------------------------------------- Constants ----------------------------------------------------------
 BASE_URI_TAG: str = "baseUri"
 COMMENTS_TAG: str = "comments"
+USER_AGENT_TAG: str = "User-Agent"
 DOMAIN_TAG: str = "domain"
 ICON_TAG: str = "icon"
 INVERSE_OF_TAG: str = "inverseOf"
@@ -74,6 +77,7 @@ class OntologyService(WacomServiceAPIClient):
             List of ontology contexts
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(f'{self.service_base_url}{OntologyService.CONTEXT_ENDPOINT}',
@@ -105,6 +109,7 @@ class OntologyService(WacomServiceAPIClient):
             List of ontology classes. Tuple<Classname, Superclass>
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(f'{self.service_base_url}{OntologyService.CONCEPTS_ENDPOINT.format(context)}',
@@ -139,6 +144,7 @@ class OntologyService(WacomServiceAPIClient):
             List of ontology contexts
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         context_url: str = urllib.parse.quote_plus(context_name)
@@ -179,6 +185,7 @@ class OntologyService(WacomServiceAPIClient):
             Instance of the concept
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         context_url: str = urllib.parse.quote_plus(context_name)
@@ -212,6 +219,7 @@ class OntologyService(WacomServiceAPIClient):
             Instance of the property
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         context_url: str = urllib.parse.quote_plus(context_name)
@@ -258,6 +266,7 @@ class OntologyService(WacomServiceAPIClient):
             If the ontology service returns an error code, exception is thrown.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         payload: Dict[str, Any] = {
@@ -316,6 +325,7 @@ class OntologyService(WacomServiceAPIClient):
             If the ontology service returns an error code, exception is thrown.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         payload: Dict[str, Any] = {
@@ -385,6 +395,7 @@ class OntologyService(WacomServiceAPIClient):
             If the ontology service returns an error code, exception is thrown.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         payload: Dict[str, Any] = {
@@ -454,6 +465,7 @@ class OntologyService(WacomServiceAPIClient):
             If the ontology service returns an error code, exception is thrown.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         payload: Dict[str, Any] = {
@@ -511,6 +523,7 @@ class OntologyService(WacomServiceAPIClient):
             If the ontology service returns an error code, exception is thrown.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         payload: Dict[str, Any] = {
@@ -543,6 +556,7 @@ class OntologyService(WacomServiceAPIClient):
             Name of the context.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         context_url: str = urllib.parse.quote_plus(context_name)
@@ -569,6 +583,7 @@ class OntologyService(WacomServiceAPIClient):
             Ontology as RDFS / OWL  ontology
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         context_url: str = urllib.parse.quote_plus(context_name)
